@@ -1,3 +1,5 @@
+from typing import List
+
 from ConfigSpace.configuration_space import ConfigurationSpace
 
 from dswizard.components.base import PreprocessingAlgorithm
@@ -14,7 +16,7 @@ class NormalizerComponent(PreprocessingAlgorithm):
         from sklearn.preprocessing import Normalizer
         return Normalizer(norm=self.norm)
 
-    def get_feature_names_out(self, input_features: list[str] = None):
+    def get_feature_names_out(self, input_features: List[str] = None):
         from sklearn.utils.validation import _check_feature_names_in
         return _check_feature_names_in(self, input_features)
 
